(* pselcss.mli     CSS functions for Psellos apps
 *
 * Copyright (c) 2022 Psellos   http://psellos.com
 *
 * Licensed under the MIT license:
 *     http://opensource.org/licenses/MIT
 *)
open Js_of_ocaml

type bdcolor = float * float * float * float
    (** A broken-down color is exposed as (r, g, b, a) with all four
     * values in [0.0, 1.0].
     *)

type color = CSS.Color.js_t
    (** Short name for JSOO color, a private subtype of Js.js_string
     * Js.t.
     *)


val length_px : float -> Js.js_string Js.t
    (** Convert a number of pixels (as a floating value) to a CSS
     * length value.
     *)

val px_length : Js.js_string Js.t -> float
    (** Convert a CSS length value to a number of pixels (as a floating
     * value).
     *)

val url_string : string -> Js.js_string Js.t
    (** Convert a URL in string form to a CSS url.
     *)

val color_bdcolor : bdcolor -> color
    (** Convert a broken-down color to a JSOO color.
     *)
